@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate test stubs for methods
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -20,9 +20,16 @@ has class => (
 
 has name => (
     is      => 'ro',
-    default => sub { 't/test.t' },
+    builder => 1,
 );
 
+sub _build_name {
+    my ($self) = @_;
+    ( my $name = $self->class ) =~ s/::/-/g;
+    $name = lc $name;
+    return "$name.t";
+}
+
 
 sub gather_methods {
     my ($self) = @_;
@@ -78,6 +85,7 @@ END
     }
 
     for my $method ( sort keys %$methods ) {
+        next if $method =~ /^_/;
         my $test = $self->unit_test($method);
         $text .= "$test\n\n";
     }
@@ -99,7 +107,7 @@ Test::NaiveStubs - Generate test stubs for methods
 
 =head1 VERSION
 
-version 0.0102
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -125,7 +133,8 @@ The class name to use in the test generation.
 
 =head2 name
 
-The test output file name. Default: t/test.t
+The test output file name.  If not given in the constructor, the filename is
+created from the B<class>.  So C<Foo::Bar> would be converted to C<foo-bar.t>.
 
 =head1 METHODS
 
